Name:		shim
Version:	15.8
Release:	1.0.7%{?dist}
Summary:	First-stage UEFI bootloader
License:	BSD
URL:		https://github.com/rhboot/shim/
BuildRequires:	efi-filesystem
BuildRequires:	efi-srpm-macros >= 6

ExclusiveArch:	%{efi}
# and we don't have shim-unsigned-arm builds *yet*
ExcludeArch:	%{arm} %{ix86}

Source0:	shim.rpmmacros
Source1:	secureboot.cer
Source2:	securebootca.cer

# keep these two lists of sources synched up arch-wise.  That is 0 and 10
# match, 1 and 11 match, ...
Source10:	BOOTAA64.CSV
Source20:	shimaa64.efi
Source30:	mmaa64.efi
Source40:	fbaa64.efi
Source50:	shimaa64-oracle.efi
Source12:	BOOTX64.CSV
Source22:	shimx64.efi
Source32:	mmx64.efi
Source42:	fbx64.efi
Source52:	shimx64-oracle.efi
#Source13:	BOOTARM.CSV
#Source23:	shimarm.efi
#Source33:	mmarm.efi
#Source43:	fbarm.efi

%include %{SOURCE0}

BuildRequires:	pesign >= 0.112-20.fc27
# We need this because %%{efi} won't expand before choosing where to make
# the src.rpm in koji, and we could be on a non-efi architecture, in which
# case we won't have a valid expansion here...  To be solved in the future
# (shim 16+) by making the unsigned packages all provide "shim-unsigned", so
# we can just BuildRequires that.
%ifarch x86_64
BuildRequires:	%{unsignedx64} = %{shimverx64}
%endif
%ifarch aarch64
BuildRequires:	%{unsignedaa64} = %{shimveraa64}
%endif
#%%ifarch arm
#BuildRequires:	%%{unsignedarm} = %%{shimverarm}
#%%endif

%description
Initial UEFI bootloader that handles chaining to a trusted full bootloader
under secure boot environments. This package contains the version signed by
the UEFI signing service.

%define_pkg -a %{efi_arch} -p 1
%if %{efi_has_alt_arch}
%define_pkg -a %{efi_alt_arch}
%endif

%prep
cd %{_builddir}
rm -rf shim-%{version}
mkdir shim-%{version}

%build
export PS4='${LINENO}: '

cd shim-%{version}
%if %{efi_has_alt_arch}
%define_build -a %{efi_alt_arch} -A %{efi_alt_arch_upper} -i %{shimefialt} -b no -c %{is_alt_signed} -d %{shimdiralt}
%endif
%define_build -a %{efi_arch} -A %{efi_arch_upper} -i %{shimefi} -b no -c %{is_signed} -d %{shimdir}

%install
rm -rf $RPM_BUILD_ROOT
cd shim-%{version}
install -D -d -m 0755 $RPM_BUILD_ROOT/boot/
install -D -d -m 0700 $RPM_BUILD_ROOT%{efi_esp_root}/
install -D -d -m 0700 $RPM_BUILD_ROOT%{efi_esp_efi}/
install -D -d -m 0700 $RPM_BUILD_ROOT%{efi_esp_dir}/
install -D -d -m 0700 $RPM_BUILD_ROOT%{efi_esp_boot}/

%do_install -a %{efi_arch} -A %{efi_arch_upper} -b %{bootcsv}
%if %{efi_has_alt_arch}
%do_install -a %{efi_alt_arch} -A %{efi_alt_arch_upper} -b %{bootcsvalt}
%endif

%if %{provide_legacy_shim}
install -m 0700 %{shimefi} $RPM_BUILD_ROOT%{efi_esp_dir}/shim.efi
%endif

( cd $RPM_BUILD_ROOT ; find .%{efi_esp_root} -type f ) \
  | sed -e 's/\./\^/' -e 's,^\\\./,.*/,' -e 's,$,$,' > %{__brp_mangle_shebangs_exclude_from_file}

%define_files -a %{efi_arch} -A %{efi_arch_upper}
%if %{efi_has_alt_arch}
%define_files -a %{efi_alt_arch} -A %{efi_alt_arch_upper}
%endif

%if %{provide_legacy_shim}
%{efi_esp_dir}/shim.efi
%endif

%changelog
* Wed Jun 04 2025 Ilya Okomin <ilya.okomin@oracle.com> - 15.8-1.0.7
- Add support for Oracle signed shim [Orabug: 38029694]
- Add vendor shim binaries signed with Oracle Secure Boot Signing (key 2) [Orabug: 38029694]

* Sat Mar 15 2025 Ilya Okomin <ilya.okomin@oracle.com> - 15.8-1.0.6
- Update shim-unsigned v15.8 providing Oracle SecureBoot CA [Orabug: 37631105]

* Wed Feb 12 2025 Mark Will <mark.will@oracle.com> - 15.8-1.0.5
- Add back oracle(*) deps and rebuild for prod signing [Orabug: 37585705]

* Thu Sep 05 2024 Alex Burmashev <alexander.burmashev@oracle.com> - 15.8-1.0.4
- Drop oracle(*) deps for test build for OL10 exercise

* Mon Mar 25 2024 Ilya Okomin <ilya.okomin@oracle.com> - 15.8-1.0.3
- Update shimx64.efi and shimaa64.efi v15.8 signed by Microsoft [Orabug: 36072879]
- Update shim fb and mm binaries to match unsigned releases [Orabug: 36072879]

* Wed Feb 07 2024 Alex Burmashev <alexander.burmashev@oracle.com> - 15.8-1.0.2
- Use binaries with correct shim.ol generation [Orabug: 36072879]
- Set SBAT_AUTOMATIC_DATE=2021030218 [Orabug: 36072879]


* Wed Jan 24 2024 Alex Burmashev <alexander.burmashev@oracle.com> - 15.8-1.0.1
- Update to 15.8 [Orabug: 36072879]
- fix CVE-2023-40546, CVE-2023-40547, CVE-2023-40548, CVE-2023-40549, CVE-2023-40550, CVE-2023-40551 [Orabug: 36072879]

* Fri Jan 06 2023 Ilya Okomin <ilya.okomin@oracle.com> - 15.7-1.0.3
- Update to shim-unsigned v15.7-1.0.2 [Orabug: 34821869]
- Update shimx64.efi and shimaa64.efi signed by Microsoft [Orabug: 34821869]

* Mon Dec 05 2022 Ilya Okomin <ilya.okomin@oracle.com> - 15.7-1.0.2
- Make sbat_var.S parse right with buggy gcc/binutils [Orabug: 34848038]

* Thu Nov 17 2022 Ilya Okomin <ilya.okomin@oracle.com> - 15.7-1.0.1
- Update to shim-unsigned-x64 15.7-1.0.1 [Orabug: 34821869]

* Thu Nov 03 2022 Ilya Okomin <ilya.okomin@oracle.com> - 15.6-1.0.4
- Rebase to shim v15.6-1 [Orabug: 34821869]
- Update vendor certs [Orabug: 34821869]
- Update oracle(grub2-sig-key) [Orabug: 34821869]
- Update shim-unsigned to v15.6-1.0.3 [Orabug: 34821869]

* Mon Jun 06 2022 Peter Jones <pjones@redhat.com> - 15.6-1.el9
- Update to shim-15.6
  Resolves: CVE-2022-28737

* Thu Apr 14 2022 Peter Jones <pjones@redhat.com> - 15.5-2.el9
- Attempt to make aarch64 build.
  Related: rhbz#1932057

* Thu Apr 14 2022 Peter Jones <pjones@redhat.com> - 15.5-1.el9
- Rebuild for rhel-9.0.0
  Resolves: rhbz#1932057

* Mon Sep 21 2020 Javier Martinez Canillas <javierm@redhat.com> - 15-16
- Fix an incorrect allocation size

* Fri Jul 31 2020 Peter Jones <pjones@redhat.com> - 15-15
- Update once again for new signed shim builds.

* Tue Jul 28 2020 Peter Jones <pjones@redhat.com> - 15-14
- Get rid of our %%dist hack for now.

* Tue Jul 28 2020 Peter Jones <pjones@redhat.com> - 15-13
- New signing keys

* Thu Jun 11 2020 Javier Martinez Canillas <javierm@redhat.com> - 15-12
- Fix firmware update bug in aarch64 caused by shim ignoring arguments
- Fix a shim crash when attempting to netboot

* Fri Jun 07 2019 Javier Martinez Canillas <javierm@redhat.com> - 15-11
- Update the shim-unsigned-aarch64 version number

* Fri Jun 07 2019 Javier Martinez Canillas <javierm@redhat.com> - 15-10
- Add a gating.yaml file so the package can be properly gated

* Wed Jun 05 2019 Javier Martinez Canillas <javierm@redhat.com> - 15-9
- Bump the NVR

* Wed Jun 05 2019 Javier Martinez Canillas <javierm@redhat.com> - 15-7
- Make EFI variable copying fatal only on secureboot enabled systems
- Fix booting shim from an EFI shell using a relative path

* Thu Mar 14 2019 Peter Jones <pjones@redhat.com> - 15-6
- Fix MoK mirroring issue which breaks kdump without intervention

* Thu Jan 24 2019 Peter Jones <pjones@redhat.com> - 15-5
- Rebuild for signing once again. If the signer actually works, then:

* Tue Oct 16 2018 Peter Jones <pjones@redhat.com> - 15-4
- Rebuild for signing

* Mon Aug 13 2018 Troy Dawson <tdawson@redhat.com>
- Release Bumped for el8 Mass Rebuild

* Sat Aug 11 2018 Troy Dawson <tdawson@redhat.com>
- Release Bumped for el8+8 Mass Rebuild

* Mon Jul 23 2018 Peter Jones <pjones@redhat.com> - 15-1
- Build for RHEL 8
